package com.ruoyi.postCheck.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.postCheck.mapper.PostProgrammeTemplateMapper;
import com.ruoyi.postCheck.domain.PostProgrammeTemplate;
import com.ruoyi.postCheck.service.IPostProgrammeTemplateService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

/**
 * 岗检方案模板Service业务层处理
 *
 * @author csg
 * @date 2023-12-19
 */
@Service
public class PostProgrammeTemplateServiceImpl extends ServiceImpl<PostProgrammeTemplateMapper, PostProgrammeTemplate> implements IPostProgrammeTemplateService
{
    @Autowired
    private PostProgrammeTemplateMapper postProgrammeTemplateMapper;

    /**
     * 查询岗检方案模板
     *
     * @param id 岗检方案模板主键
     * @return 岗检方案模板
     */
    @Override
    public PostProgrammeTemplate selectPostProgrammeTemplateById(Long id)
    {
        return postProgrammeTemplateMapper.selectPostProgrammeTemplateById(id);
    }

    /**
     * 查询岗检方案模板列表
     *
     * @param postProgrammeTemplate 岗检方案模板
     * @return 岗检方案模板
     */
    @Override
    public List<PostProgrammeTemplate> selectPostProgrammeTemplateList(PostProgrammeTemplate postProgrammeTemplate)
    {
        return postProgrammeTemplateMapper.selectPostProgrammeTemplateList(postProgrammeTemplate);
    }

    /**
     * 新增岗检方案模板
     *
     * @param postProgrammeTemplate 岗检方案模板
     * @return 结果
     */
    @Override
    public int insertPostProgrammeTemplate(PostProgrammeTemplate postProgrammeTemplate)
    {
        postProgrammeTemplate.setCreateDefault();
        return postProgrammeTemplateMapper.insertPostProgrammeTemplate(postProgrammeTemplate);
    }

    /**
     * 修改岗检方案模板
     *
     * @param postProgrammeTemplate 岗检方案模板
     * @return 结果
     */
    @Override
    public int updatePostProgrammeTemplate(PostProgrammeTemplate postProgrammeTemplate)
    {
        postProgrammeTemplate.setUpdateDefault();
        return postProgrammeTemplateMapper.updatePostProgrammeTemplate(postProgrammeTemplate);
    }

    /**
     * 批量删除岗检方案模板
     *
     * @param ids 需要删除的岗检方案模板主键
     * @return 结果
     */
    @Override
    public int deletePostProgrammeTemplateByIds(Long[] ids)
    {
        return postProgrammeTemplateMapper.deletePostProgrammeTemplateByIds(ids);
    }

    /**
     * 删除岗检方案模板信息
     *
     * @param id 岗检方案模板主键
     * @return 结果
     */
    @Override
    public int deletePostProgrammeTemplateById(Long id)
    {
        return postProgrammeTemplateMapper.deletePostProgrammeTemplateById(id);
    }
}
